@@ -18,12 +18,12 @@ from typing import TYPE_CHECKING, Any, Dict, Union
 
 from supertokens_python.ingredients.emaildelivery import \
     EmailDeliveryIngredient
-from supertokens_python.types import APIResponse
+from supertokens_python.types import APIResponse, GeneralErrorResponse
 
 if TYPE_CHECKING:
     from supertokens_python.framework import BaseRequest, BaseResponse
 
-    from .types import User
+    from .types import User, VerificationEmailTemplateVars
     from .utils import EmailVerificationConfig
 
 
@@ -81,7 +81,7 @@ class RecipeInterface(ABC):
 class APIOptions:
     def __init__(self, request: BaseRequest, response: BaseResponse, recipe_id: str,
                  config: EmailVerificationConfig, recipe_implementation: RecipeInterface,
-                 email_delivery: EmailDeliveryIngredient[TypeEmailVerificationEmailDeliveryInput]):
+                 email_delivery: EmailDeliveryIngredient[VerificationEmailTemplateVars]):
         self.request = request
         self.response = response
         self.recipe_id = recipe_id
@@ -149,24 +149,6 @@ class GenerateEmailVerifyTokenPostEmailAlreadyVerifiedError(
         }
 
 
-class TypeEmailVerificationEmailDeliveryInputUser:
-    def __init__(self, user_id: str, email: str):
-        self.id = user_id
-        self.email = email
-
-
-class TypeEmailVerificationEmailDeliveryInput:
-    def __init__(
-        self,
-        user: TypeEmailVerificationEmailDeliveryInputUser,
-        email_verify_link: str,
-        user_context: Dict[str, Any],
-    ) -> None:
-        self.user = user
-        self.email_verify_link = email_verify_link
-        self.user_context = user_context
-
-
 class APIInterface(ABC):
     def __init__(self):
         self.disable_email_verify_post = False
@@ -174,14 +156,14 @@ class APIInterface(ABC):
         self.disable_generate_email_verify_token_post = False
 
     @abstractmethod
-    async def email_verify_post(self, token: str, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[EmailVerifyPostOkResult, EmailVerifyPostInvalidTokenError]:
+    async def email_verify_post(self, token: str, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[EmailVerifyPostOkResult, EmailVerifyPostInvalidTokenError, GeneralErrorResponse]:
         pass
 
     @abstractmethod
-    async def is_email_verified_get(self, api_options: APIOptions, user_context: Dict[str, Any]) -> IsEmailVerifiedGetOkResult:
+    async def is_email_verified_get(self, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[IsEmailVerifiedGetOkResult, GeneralErrorResponse]:
         pass
 
     @abstractmethod
     async def generate_email_verify_token_post(self, api_options: APIOptions,
-                                               user_context: Dict[str, Any]) -> Union[GenerateEmailVerifyTokenPostOkResult, GenerateEmailVerifyTokenPostEmailAlreadyVerifiedError]:
+                                               user_context: Dict[str, Any]) -> Union[GenerateEmailVerifyTokenPostOkResult, GenerateEmailVerifyTokenPostEmailAlreadyVerifiedError, GeneralErrorResponse]:
         pass
