@@ -21,8 +21,9 @@ from supertokens_python.ingredients.emaildelivery.types import \
 
 from . import exceptions as ex
 from . import providers, utils
+from .emaildelivery import services as emaildelivery_services
 from .recipe import ThirdPartyRecipe
-from .types import TypeThirdPartyEmailDeliveryInput
+from .types import EmailTemplateVars
 
 InputEmailVerificationConfig = utils.InputEmailVerificationConfig
 InputOverrideConfig = utils.InputOverrideConfig
@@ -34,6 +35,7 @@ Github = providers.Github
 Google = providers.Google
 GoogleWorkspaces = providers.GoogleWorkspaces
 exceptions = ex
+SMTPService = emaildelivery_services.SMTPService
 
 if TYPE_CHECKING:
     from supertokens_python.supertokens import AppInfo
@@ -44,7 +46,7 @@ if TYPE_CHECKING:
 def init(sign_in_and_up_feature: SignInAndUpFeature,
          email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
          override: Union[InputOverrideConfig, None] = None,
-         email_delivery: Union[EmailDeliveryConfig[TypeThirdPartyEmailDeliveryInput], None] = None
+         email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None
          ) -> Callable[[AppInfo], RecipeModule]:
     return ThirdPartyRecipe.init(
         sign_in_and_up_feature, email_verification_feature, override, email_delivery)
