@@ -22,16 +22,16 @@ from supertokens_python.recipe.emailverification.interfaces import \
     CreateEmailVerificationTokenOkResult
 from supertokens_python.recipe.session.asyncio import create_new_session
 from supertokens_python.recipe.thirdparty.interfaces import (
-    APIInterface, AuthorisationUrlGetOkResult, SignInUpFieldError,
-    SignInUpPostFieldError, SignInUpPostNoEmailGivenByProviderResponse,
-    SignInUpPostOkResult)
+    APIInterface, AuthorisationUrlGetOkResult,
+    SignInUpPostNoEmailGivenByProviderResponse, SignInUpPostOkResult)
 from supertokens_python.recipe.thirdparty.types import UserInfo
 
 if TYPE_CHECKING:
-    from supertokens_python.recipe.thirdparty.interfaces import (
-        APIOptions)
+    from supertokens_python.recipe.thirdparty.interfaces import APIOptions
     from supertokens_python.recipe.thirdparty.provider import Provider
 
+from supertokens_python.types import GeneralErrorResponse
+
 DEV_OAUTH_CLIENT_IDS = [
     '1060725074195-kmeum4crr01uirfl2op9kd5acmi9jutn.apps.googleusercontent.com',
     # google client id
@@ -54,7 +54,7 @@ def get_actual_client_id_from_development_client_id(client_id: str):
 
 
 class APIImplementation(APIInterface):
-    async def authorisation_url_get(self, provider: Provider, api_options: APIOptions, user_context: Dict[str, Any]) -> AuthorisationUrlGetOkResult:
+    async def authorisation_url_get(self, provider: Provider, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[AuthorisationUrlGetOkResult, GeneralErrorResponse]:
         authorisation_url_info = provider.get_authorisation_redirect_api_info(user_context)
 
         params: Dict[str, str] = {}
@@ -87,7 +87,7 @@ class APIImplementation(APIInterface):
         url = auth_url + '?' + query_string
         return AuthorisationUrlGetOkResult(url)
 
-    async def sign_in_up_post(self, provider: Provider, code: str, redirect_uri: str, client_id: Union[str, None], auth_code_response: Union[Dict[str, Any], None], api_options: APIOptions, user_context: Dict[str, Any]) -> Union[SignInUpPostOkResult, SignInUpPostNoEmailGivenByProviderResponse, SignInUpPostFieldError]:
+    async def sign_in_up_post(self, provider: Provider, code: str, redirect_uri: str, client_id: Union[str, None], auth_code_response: Union[Dict[str, Any], None], api_options: APIOptions, user_context: Dict[str, Any]) -> Union[SignInUpPostOkResult, SignInUpPostNoEmailGivenByProviderResponse, GeneralErrorResponse]:
 
         redirect_uri_from_provider = provider.get_redirect_uri(user_context)
         if is_using_oauth_development_client_id(provider.get_client_id(user_context)):
@@ -117,11 +117,7 @@ class APIImplementation(APIInterface):
         except Exception as e:
             raise_general_exception(e)
 
-        user_info: UserInfo
-        try:
-            user_info = await provider.get_profile_info(access_token_response, user_context)
-        except Exception as e:
-            return SignInUpPostFieldError(str(e))
+        user_info: UserInfo = await provider.get_profile_info(access_token_response, user_context)
         email = user_info.email.id if user_info.email is not None else None
         email_verified = user_info.email.is_verified if user_info.email is not None else None
         if email is None or email_verified is None:
@@ -129,9 +125,6 @@ class APIImplementation(APIInterface):
 
         signinup_response = await api_options.recipe_implementation.sign_in_up(provider.id, user_info.user_id, email, email_verified, user_context)
 
-        if isinstance(signinup_response, SignInUpFieldError):
-            return SignInUpPostFieldError(signinup_response.error)
-
         if email_verified:
             token_response = await api_options.email_verification_recipe_implementation.create_email_verification_token(user_id=signinup_response.user.user_id, email=signinup_response.user.email, user_context=user_context)
 
