@@ -27,7 +27,7 @@ from ...passwordless.interfaces import (
     RevokeAllCodesOkResult, RevokeCodeOkResult,
     UpdateUserEmailAlreadyExistsError, UpdateUserOkResult,
     UpdateUserPhoneNumberAlreadyExistsError, UpdateUserUnknownUserIdError)
-from ...thirdparty.interfaces import SignInUpFieldError, SignInUpOkResult
+from ...thirdparty.interfaces import SignInUpOkResult
 
 if TYPE_CHECKING:
     from supertokens_python.querier import Querier
@@ -145,7 +145,7 @@ class RecipeImplementation(RecipeInterface):
         return User(user_id=tp_user.user_id, email=tp_user.email, time_joined=tp_user.time_joined, third_party_info=tp_user.third_party_info, phone_number=None)
 
     async def thirdparty_sign_in_up(self, third_party_id: str, third_party_user_id: str, email: str,
-                                    email_verified: bool, user_context: Dict[str, Any]) -> Union[SignInUpOkResult, SignInUpFieldError]:
+                                    email_verified: bool, user_context: Dict[str, Any]) -> SignInUpOkResult:
         if self.tp_sign_in_up is None:
             raise Exception("No thirdparty provider configured")
         return await self.tp_sign_in_up(third_party_id, third_party_user_id, email, email_verified, user_context)
