@@ -29,17 +29,14 @@ from supertokens_python import InputAppInfo, SupertokensConfig, init
 from supertokens_python.framework.fastapi import get_middleware
 from supertokens_python.ingredients.smsdelivery.services.supertokens import \
     SUPERTOKENS_SMS_SERVICE_URL
-from supertokens_python.ingredients.smsdelivery.services.twilio import (
-    GetContentResult, ServiceInterface, SMSDeliveryTwilioConfig,
-    TwilioServiceConfig)
 from supertokens_python.ingredients.smsdelivery.types import (
-    SMSDeliveryConfig, SMSDeliveryInterface)
+    SMSDeliveryConfig, SMSDeliveryInterface, TwilioSettings, SMSContent, TwilioServiceInterface)
 from supertokens_python.querier import Querier
 from supertokens_python.recipe import passwordless, session
 from supertokens_python.recipe.passwordless.smsdelivery.services.twilio import \
     TwilioService
 from supertokens_python.recipe.passwordless.types import \
-    TypePasswordlessSmsDeliveryInput
+    SMSTemplateVars
 from supertokens_python.utils import is_version_gte
 from tests.utils import (clean_st, reset, setup_st, sign_in_up_request_phone,
                          start_st)
@@ -177,16 +174,16 @@ async def test_pless_login_default_backward_compatibility_no_suppress_error_for_
     with respx_mock(assert_all_mocked=False) as mocker:
         mocker.route(host="localhost").pass_through()
         mocked_route = mocker.post(SUPERTOKENS_SMS_SERVICE_URL).mock(side_effect=api_side_effect)
-        resp = sign_in_up_request_phone(driver_config_client, "+919909909998", True)
+        try:
+            sign_in_up_request_phone(driver_config_client, "+919909909998", True)
+        except Exception as e:
+            assert str(e) == "CUSTOM_ERR"
+            assert mocked_route.called
 
-        assert resp.status_code == 200
-        assert resp.json() == {'status': 'GENERAL_ERROR', 'message': 'CUSTOM_ERR'}
-        assert mocked_route.called
-
-        assert app_name == "ST"
-        assert phone == "+919909909998"
-        assert all([url_with_link_code, user_input_code, code_lifetime])
-        assert code_lifetime > 0
+            assert app_name == "ST"
+            assert phone == "+919909909998"
+            assert all([url_with_link_code, user_input_code, code_lifetime])
+            assert code_lifetime > 0
 
 
 @mark.asyncio
@@ -259,7 +256,7 @@ async def test_pless_login_backward_compatibility(driver_config_client: TestClie
     url_with_link_code = ""
     user_input_code = ""
 
-    async def create_and_send_custom_text_message(input_: TypePasswordlessSmsDeliveryInput, _: Dict[str, Any]):
+    async def create_and_send_custom_text_message(input_: SMSTemplateVars, _: Dict[str, Any]):
         nonlocal phone, code_lifetime, url_with_link_code, user_input_code
         phone = input_.phone_number
         code_lifetime = input_.code_life_time
@@ -306,17 +303,17 @@ async def test_pless_login_custom_override(driver_config_client: TestClient):
     user_input_code = ""
     app_name = ""
 
-    def sms_delivery_override(oi: SMSDeliveryInterface[TypePasswordlessSmsDeliveryInput]):
+    def sms_delivery_override(oi: SMSDeliveryInterface[SMSTemplateVars]):
         oi_send_sms = oi.send_sms
 
-        async def send_sms(input_: TypePasswordlessSmsDeliveryInput, user_context: Dict[str, Any]):
+        async def send_sms(template_vars: SMSTemplateVars, user_context: Dict[str, Any]):
             nonlocal phone, url_with_link_code, user_input_code, code_lifetime
-            phone = input_.phone_number
-            url_with_link_code = input_.url_with_link_code
-            user_input_code = input_.user_input_code
-            code_lifetime = input_.code_life_time
+            phone = template_vars.phone_number
+            url_with_link_code = template_vars.url_with_link_code
+            user_input_code = template_vars.user_input_code
+            code_lifetime = template_vars.code_life_time
 
-            await oi_send_sms(input_, user_context)
+            await oi_send_sms(template_vars, user_context)
 
         oi.send_sms = send_sms
         return oi
@@ -375,12 +372,12 @@ async def test_pless_login_smtp_service(driver_config_client: TestClient):
     get_content_called, send_raw_email_called, outer_override_called = False, False, False
     twilio_api_called = False
 
-    def twilio_service_override(oi: ServiceInterface[TypePasswordlessSmsDeliveryInput]):
+    def twilio_service_override(oi: TwilioServiceInterface[SMSTemplateVars]):
 
         oi_send_raw_sms = oi.send_raw_sms
 
         async def send_raw_email_override(
-            get_content_result: GetContentResult,
+            content: SMSContent,
             _user_context: Dict[str, Any],
             from_: Union[str, None] = None,
             messaging_service_sid: Union[str, None] = None,
@@ -388,22 +385,22 @@ async def test_pless_login_smtp_service(driver_config_client: TestClient):
             nonlocal send_raw_email_called, phone, user_input_code
             send_raw_email_called = True
 
-            assert get_content_result.body == user_input_code
-            assert get_content_result.to_phone == "+919909909998"
-            phone = get_content_result.to_phone
+            assert content.body == user_input_code
+            assert content.to_phone == "+919909909998"
+            phone = content.to_phone
 
-            await oi_send_raw_sms(get_content_result, _user_context, from_, messaging_service_sid)
+            await oi_send_raw_sms(content, _user_context, from_, messaging_service_sid)
 
-        async def get_content_override(input_: TypePasswordlessSmsDeliveryInput, _user_context: Dict[str, Any]) -> GetContentResult:
+        async def get_content_override(template_vars: SMSTemplateVars, _user_context: Dict[str, Any]) -> SMSContent:
             nonlocal get_content_called, user_input_code, code_lifetime
             get_content_called = True
 
-            user_input_code = input_.user_input_code or ""
-            code_lifetime = input_.code_life_time
+            user_input_code = template_vars.user_input_code or ""
+            code_lifetime = template_vars.code_life_time
 
-            return GetContentResult(
+            return SMSContent(
                 body=user_input_code,
-                to_phone=input_.phone_number
+                to_phone=template_vars.phone_number
             )
 
         oi.send_raw_sms = send_raw_email_override
@@ -412,23 +409,21 @@ async def test_pless_login_smtp_service(driver_config_client: TestClient):
         return oi
 
     twilio_sms_delivery_service = TwilioService(
-        config=SMSDeliveryTwilioConfig(
-            twilio_settings=TwilioServiceConfig(
-                account_sid="ACTWILIO_ACCOUNT_SID",
-                auth_token="test-token",
-                from_="+919909909999",
-            ),
-            override=twilio_service_override,
-        )
+        twilio_settings=TwilioSettings(
+            account_sid="ACTWILIO_ACCOUNT_SID",
+            auth_token="test-token",
+            from_="+919909909999",
+        ),
+        override=twilio_service_override,
     )
 
-    def sms_delivery_override(oi: SMSDeliveryInterface[TypePasswordlessSmsDeliveryInput]) -> SMSDeliveryInterface[TypePasswordlessSmsDeliveryInput]:
+    def sms_delivery_override(oi: SMSDeliveryInterface[SMSTemplateVars]) -> SMSDeliveryInterface[SMSTemplateVars]:
         oi_send_sms = oi.send_sms
 
-        async def send_sms_override(input_: TypePasswordlessSmsDeliveryInput, user_context: Dict[str, Any]):
+        async def send_sms_override(template_vars: SMSTemplateVars, user_context: Dict[str, Any]):
             nonlocal outer_override_called
             outer_override_called = True
-            await oi_send_sms(input_, user_context)
+            await oi_send_sms(template_vars, user_context)
 
         oi.send_sms = send_sms_override
         return oi
